# A different file to pycallgraph.py because of circular import problem

__version__ = '2.1.1'
__copyright__ = 'Copyright Gerald Kaszuba 2007-2024'
__license__ = 'GPLv2'
__author__ = 'Gerald Kaszuba'
__email__ = 'pycallgraph@gakman.com'
__url__ = 'http://pycallgraph.readthedocs.io/'
__credits__ = [
    'Gerald Kaszuba',
    'Lewis Cowles',
]
